@@ -26,8 +26,8 @@
 #include <config.h>
 #endif /* HAVE_CONFIG_H */
 
-#include <glib-object.h>
 #include <glib.h>
+#include <glib-object.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
 #include <glade/glade.h>
@@ -46,21 +46,21 @@ static void cria_open_presentation_from_filename (char const *filename);
   // GObject used methods
 static void cria_application_init (CriaApplication* self);
 
-//int x = -1, y, w = -1, h = -1, d = 0;
+//int x = -1, y, w = -1, h = -1;
 //char *debug_modules = NULL;
 
-gboolean	start_off = 0;
+gboolean	start_off = 0,
+		debug     = 0;
 
-static const struct poptOption options[] =
-{
+static const struct poptOption options[] = {
+	{"debug", '\0', POPT_ARG_NONE, &debug, 0, N_("Enable debugging"), NULL},
+	{"start-off", 's', POPT_ARG_NONE, &start_off, 0,
+		N_("Start a presentation (and open a file selection if no file "
+			"is given at the command line)"), NULL},
 //	{NULL, 'x', POPT_ARG_INT, &x, 0, N_("X position of window"), N_("X")},
 //	{NULL, 'y', POPT_ARG_INT, &y, 0, N_("Y position of window"), N_("Y")},
 //	{NULL, 'w', POPT_ARG_INT, &w, 0, N_("width of window"), N_("WIDTH")},
 //	{NULL, 'h', POPT_ARG_INT, &h, 0, N_("height of window"), N_("WIDTH")},
-	{"start-off", 's', POPT_ARG_NONE, &start_off, 0,
-		N_("Start a presentation (and open a file selection if no file "
-			"is given at the command line)"), NULL},
-//	{"debug", '\0', POPT_ARG_NONE, &d, 0, N_("Enable debugging"), NULL},
 /*	{"debug-modules", '\0', POPT_ARG_STRING, &debug_modules, 0,
 		N_("Modules to enable debugging in"), N_("MODULES")},
 */	{NULL, '\0', 0, NULL, 0}
@@ -81,22 +81,21 @@ struct _CriaApplicationPriv {
 
 static	CriaApplication	* instance = NULL;
 
-const gchar*	  cria_application_get_attribute (CriaApplication	* self);
-void		  cria_application_set_attribute (CriaApplication	* self,
-						const char	* attribute);
-static	void	cria_application_get_property	       (GObject		* object,
+static	void	  cria_application_get_property(GObject		* object,
 						guint		  prop_id,
 						GValue		* value,
 						GParamSpec	* param_spec);
-static	void	cria_application_set_property        (GObject		* object,
+static	void	  cria_application_set_property(GObject		* object,
 						guint		  prop_id,
 						const	GValue	* value,
 						GParamSpec	* param_spec);
-
+#if 0
+/* enable this to add support for signals */
 static	guint	cria_application_signals[N_SIGNALS] = { 0 };
 
 static	void	cria_application_signal	       (CriaApplication	* template,
 						const	gchar	* string);
+#endif
 
 void
 criawips_init(int *argc, char ***argv) {
@@ -161,7 +160,7 @@ criawips_init(int *argc, char ***argv) {
 			gchar		* filename;
 
 			dialog = gtk_file_chooser_dialog_new (
-					"Open File",
+					_("Select a Presentation"),
 					NULL,
 					GTK_FILE_CHOOSER_ACTION_OPEN,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -185,10 +184,10 @@ criawips_init(int *argc, char ***argv) {
 				g_assert_not_reached();
 				break;
 			};
-
 		}
 	} else {
 		g_debug("criawips_init(): opening main window(s)");
+		
 		if (!filenames) {
 			/* Open the criawips main window here */
 			cria_main_window_new (NULL);
@@ -204,7 +203,6 @@ criawips_init(int *argc, char ***argv) {
 	}
 
 	g_debug("criawips_init(): end");
-	return;
 }
 
 void
@@ -221,23 +219,10 @@ criawips_quit (void) {
  * file selection handling stuff                                             *
  *****************************************************************************/
 
-static gchar*
-construct_uri_from_absolute_path (const gchar* path) {
-	gchar	* uri;
-
-	g_assert(path != NULL);
-
-	uri = g_malloc(strlen("file://") + strlen(path) + 1);
-	g_snprintf(uri, strlen("file://") + strlen(path) + 1, "file://%s", path);
-
-	return uri;
-}
-
 static void
 cria_open_presentation_from_filename (const gchar* filename) {
 	CriaPresentation	* pres;
 	CriaSlideShow		* show;
-	gchar			* text_uri;
 	GError			* error = NULL;
 
 	g_assert(filename != NULL);
@@ -246,19 +231,14 @@ cria_open_presentation_from_filename (const gchar* filename) {
 	pres = cria_presentation_new_from_file (filename, &error);
 
 	if (error) {
-		GladeXML	* xml;
-		char		* error_message;
-
-		error_message = g_strdup_printf(
-				"<span weight=\"bold\">The Presentation could not be opened</span>\n\n"
-				"For some reason the presentation you wanted to open could not be opened. "
-				"The reason was <span style=\"italic\">%s</span>.", error->message);
-		
-		xml = glade_xml_new(PACKAGE_DATA_DIR "/" PACKAGE "/data/criawips.glade", "error_dialog", NULL);
-		gtk_label_set_markup(
-				GTK_LABEL(glade_xml_get_widget(xml, "error_label_message")),
-				error_message);
-		gtk_dialog_run(GTK_DIALOG(glade_xml_get_widget(xml, "error_dialog")));
+		char		* error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
+								  _("The Presentation could not be opened"),
+								  _("For some reason the presentation you wanted to open could not be opened."),
+								  _("The reason was:"),
+								  error->message);
+		cria_application_show_error_dialog(NULL,
+						   _("Error opening file"),
+						   error_message);
 		g_free(error_message);
 		g_error_free(error);
 		gtk_main_quit();
@@ -278,8 +258,7 @@ cria_open_presentation_from_filename (const gchar* filename) {
 //----------------------------------------------------------------------------
 
 static void
-cria_application_class_init (CriaApplicationClass	* cria_application_class)
-{
+cria_application_class_init (CriaApplicationClass* cria_application_class) {
 	GObjectClass	* g_object_class;
 
 	g_object_class = G_OBJECT_CLASS(cria_application_class);
@@ -345,8 +324,7 @@ cria_application_get_property (
 
 	self = CRIA_APPLICATION (object);
 
-	switch (prop_id)
-	{
+	switch (prop_id) {
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (
 				object,
@@ -367,13 +345,7 @@ cria_application_init (CriaApplication* self) {
 		g_critical("%s", "CriaApplication can only be instantiated once");
 	}
 }
-#if 0
-void
-cria_application_open_window(CriaApplication* self, gchar const* filename) {
-	CriaMainWindow	* mainwin =  cria_main_window_new(filename);
-	self->priv->windows = g_list_prepend(self->priv->windows, mainwin);
-}
-#endif
+
 static void
 cria_application_set_property (
 		GObject		* object,
@@ -385,8 +357,7 @@ cria_application_set_property (
 	
 	self = CRIA_APPLICATION (object);
 	
-	switch (prop_id)
-	{
+	switch (prop_id) {
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (
 				object,
@@ -396,13 +367,35 @@ cria_application_set_property (
 	}
 }
 
+void
+cria_application_show_error_dialog (GtkWindow* parent, gchar const* title, gchar const* message) {
+	GtkWidget	* dialog,
+			* label;
+
+	dialog = gtk_dialog_new_with_buttons(title,
+                                             parent,
+					     GTK_DIALOG_NO_SEPARATOR,
+					     GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
+					     NULL);
+	label = g_object_new(GTK_TYPE_LABEL,
+			     "justify", GTK_JUSTIFY_FILL,
+			     "markup", message,
+			     "wrap", TRUE,
+			     NULL);
+	gtk_widget_show(label);
+
+	gtk_container_add(GTK_CONTAINER(dialog),
+			  label);
+	
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_object_destroy(GTK_OBJECT(dialog));
+}
+
 GType
-cria_application_get_type (void)
-{
+cria_application_get_type (void) {
 	static GType	type = 0;
 
-	if (!type)
-	{
+	if (!type) {
 		const GTypeInfo info = {
 			sizeof (CriaApplicationClass),
 			NULL,	/* base initializer */
