@@ -22,12 +22,12 @@
  * USA
  */
 
-#ifndef APPLICATION_H
-#define APPLICATION_H
-
 #include <glib-object.h>
 #include "main-window.h"
 
+#ifndef APPLICATION_H
+#define APPLICATION_H
+
 G_BEGIN_DECLS
 
 typedef struct _CriaApplication CriaApplication;
@@ -40,6 +40,9 @@ void		  criawips_quit			       (void);
 CriaApplication	* cria_application_get_instance	       (void);
 GType		  cria_application_get_type	       (void);
 void		  cria_application_register_window     (CriaMainWindow	* window);
+void		  cria_application_show_error_dialog   (GtkWindow	* parent,
+							gchar const	* title,
+							gchar const	* message);
 
 #define CRIA_TYPE_APPLICATION			(cria_application_get_type ())
 #define CRIA_APPLICATION(object)		(G_TYPE_CHECK_INSTANCE_CAST((object), CRIA_TYPE_APPLICATION, CriaApplication))
@@ -54,11 +57,12 @@ struct _CriaApplication {
 };
 
 struct _CriaApplicationClass {
-	GObjectClass	  base_class;
-
+	GObjectClass		  base_class;
+#if 0
 	/* signals */
 	void (*signal)	       (CriaApplication	* template,
 				const	gchar	* string);
+#endif
 };
 
 G_END_DECLS
