@@ -40,6 +40,7 @@
 #include "presentation.h"
 #include "slide-list.h"
 #include "slide-show.h"
+#include "slide-view.h"
 
 enum {
 	PROP_0,
@@ -61,19 +62,23 @@ static	void	cria_main_window_get_property  (GObject		* object,
 						GValue		* value,
 						GParamSpec	* param_spec);
 static	void	cria_main_window_init	       (CriaMainWindow	* self);
+static	void	cria_main_window_open	       (CriaMainWindow	* self,
+						gpointer	  data);
+static	void	cria_main_window_selected_slide_changed(
+						CriaMainWindow	* self,
+						GtkTreeSelection* selection);
 static	void	cria_main_window_set_property  (GObject		* object,
 						guint		  prop_id,
 						const	GValue	* value,
 						GParamSpec	* param_spec);
+static void	  cria_main_window_set_zoom_from_spin  (CriaMainWindow  * template,
+							GtkSpinButton	* spinner);
+static	void	cria_main_window_signal		       (CriaMainWindow	* template,
+							const	gchar	* string);
+static	void	cria_main_window_start_off	       (CriaMainWindow	* self);
 
 static	guint	cria_main_window_signals[N_SIGNALS] = { 0 };
 
-static	void	cria_main_window_signal	       (CriaMainWindow	* template,
-						const	gchar	* string);
-static	void	cria_main_window_open	       (CriaMainWindow	* self,
-						gpointer	  data);
-static	void	cria_main_window_start_off     (CriaMainWindow	* self);
-
 static void
 cria_main_window_class_init (CriaMainWindowClass	* cria_main_window_class)
 {
@@ -130,24 +135,15 @@ cria_main_window_new(const gchar* filename) {
 		p = cria_presentation_new_from_file(filename, &error);
 
 		if (error) {
-			GtkWidget	* dialog = glade_xml_get_widget(self->priv->xml, "error_dialog");
-			char            * error_message;
-			
-			error_message = g_strdup_printf(
-					"<span weight=\"bold\">The Presentation could not be opened</span>\n\n"
-					"For some reason the presentation you wanted to open could not be opened. "
-					"The reason was:\n<span style=\"italic\">%s</span>.", error->message);
-
-			gtk_label_set_markup(
-					GTK_LABEL(glade_xml_get_widget(self->priv->xml, "error_label_message")),
-					error_message);
-			g_signal_connect_swapped(
-					glade_xml_get_widget(self->priv->xml, "error_button_close"),
-					"clicked",
-					G_CALLBACK(gtk_widget_hide),
-					dialog);
-			gtk_dialog_run(GTK_DIALOG(dialog));
-			
+			/* NOTE: keep these strings in sync with the ones from application.c */
+			char            * error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
+									  _("The Presentation could not be opened"),
+									  _("For some reason the presentation you wanted to open could not be opened."),
+									  _("The reason was:"),
+									  error->message);
+			cria_application_show_error_dialog(GTK_WINDOW(glade_xml_get_widget(self->priv->xml, "main_window")),
+					 		   _("Error opening file"),
+							   error_message);
 			g_free(error_message);
 			g_error_free(error);
 		} else {
@@ -244,6 +240,10 @@ cria_main_window_init(CriaMainWindow* self) {
 	// FIXME add some nice warning if this fails
 	self->priv->xml = glade_xml_new(PACKAGE_DATA_DIR "/" PACKAGE "/data/criawips.glade", NULL, NULL);
 
+	gtk_paned_set_position(
+			GTK_PANED(glade_xml_get_widget(self->priv->xml, "main_hpaned")),
+			150);
+
 	/* connecting signals */
 	  /* window */
 	g_signal_connect(glade_xml_get_widget(self->priv->xml, "main_window"),
@@ -312,6 +312,18 @@ cria_main_window_init(CriaMainWindow* self) {
 			"clicked",
 			G_CALLBACK(cria_main_window_start_off),
 			self);
+	g_signal_connect_swapped(
+			glade_xml_get_widget(self->priv->xml, "main_spinbutton_zoom"),
+			"value-changed",
+			G_CALLBACK(cria_main_window_set_zoom_from_spin),
+			self);
+
+	/* slide list */
+	g_signal_connect_swapped(
+			gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(self->priv->xml, "main_slide_list"))),
+			"changed",
+			G_CALLBACK(cria_main_window_selected_slide_changed),
+			self);
 
 	/* display the window */
 	gtk_widget_show(glade_xml_get_widget(self->priv->xml, "main_window"));
@@ -345,23 +357,15 @@ cria_main_window_open(CriaMainWindow* self, gpointer d) {
 			cria_main_window_set_presentation(self, cria_presentation_new_from_uri((gchar*)uris->data, &error));
 
 			if (error) {
-				// FIXME refactor this smart, this code currently appears three times in the source tree
-				GtkWidget	* dialog = glade_xml_get_widget(self->priv->xml, "error_dialog");
-				char            * error_message;
-				
-				error_message = g_strdup_printf(
-						"<span weight=\"bold\">The Presentation could not be opened</span>\n\n"
-						"For some reason the presentation you wanted to open could not be opened. "
-						"The reason was:\n<span style=\"italic\">%s</span>.", error->message);
-
-				gtk_label_set_markup(
-						GTK_LABEL(glade_xml_get_widget(self->priv->xml, "error_label_message")),
-						error_message);
-				g_signal_connect_swapped(
-						glade_xml_get_widget(self->priv->xml, "error_button_close"),
-						"clicked",
-						G_CALLBACK(gtk_widget_hide),
-						dialog);
+				/* NOTE: keep the string in sync with the ones from application.c */
+				char            * error_message = g_strdup_printf("<span weight=\"bold\">%s</span>\n\n%s %s:\n<span style=\"italic\">%s</span>.",
+										  _("The Presentation could not be opened"),
+										  _("For some reason the presentation you wanted to open could not be opened."),
+										  _("The reason was:"),
+										  error->message);
+				cria_application_show_error_dialog(GTK_WINDOW(glade_xml_get_widget(self->priv->xml, "main_window")),
+								   _("Error opening file"),
+								   error_message);
 				gtk_dialog_run(GTK_DIALOG(dialog));
 				
 				g_free(error_message);
@@ -375,6 +379,44 @@ cria_main_window_open(CriaMainWindow* self, gpointer d) {
 	gtk_object_destroy(GTK_OBJECT(dialog));
 }
 
+static void
+cria_main_window_selected_slide_changed(CriaMainWindow* self, GtkTreeSelection* selection) {
+	GtkWidget	* slide_view;
+	CriaSlide	* slide;
+	GtkTreeIter	  iter;
+	gint		  index;
+	gboolean	  has_selection;
+
+	g_assert(CRIA_IS_MAIN_WINDOW(self));
+	g_assert(GTK_IS_TREE_SELECTION(selection));
+
+	slide_view = glade_xml_get_widget(self->priv->xml, "main_slide_view");
+
+	has_selection = gtk_tree_selection_get_selected(
+			selection,
+			NULL,
+			&iter);
+
+	if (has_selection) {
+		gtk_tree_model_get(
+				gtk_tree_view_get_model(GTK_TREE_VIEW(glade_xml_get_widget(self->priv->xml, "main_slide_list"))), &iter,
+				COLUMN_INDEX, &index,
+				-1);
+
+		g_debug("cria_main_window_selected_slide_changed(): selected slide[%i]", index);
+
+		slide = cria_presentation_get_slide(
+				cria_main_window_get_presentation(self),
+				index);
+	} else {
+		slide = NULL;
+	}
+
+	cria_slide_view_set_slide(
+			CRIA_SLIDE_VIEW(slide_view),
+			slide);
+}
+
 void
 cria_main_window_set_presentation (
 		CriaMainWindow	* self,
@@ -391,6 +433,7 @@ cria_main_window_set_presentation (
 	if (presentation) {
 		self->priv->presentation = g_object_ref (presentation);
 		cria_slide_list_set_presentation(CRIA_SLIDE_LIST(glade_xml_get_widget(self->priv->xml, "main_slide_list")), cria_main_window_get_presentation(self));
+		cria_slide_view_set_slide(CRIA_SLIDE_VIEW(glade_xml_get_widget(self->priv->xml, "main_slide_view")), cria_presentation_get_slide(cria_main_window_get_presentation(self), 0));
 	}
 
 	g_object_notify (G_OBJECT (self), "presentation");
@@ -423,6 +466,11 @@ cria_main_window_set_property (
 	}
 }
 
+static void
+cria_main_window_set_zoom_from_spin(CriaMainWindow* self, GtkSpinButton* spinner) {
+	cria_slide_view_set_zoom(CRIA_SLIDE_VIEW(glade_xml_get_widget(self->priv->xml, "main_slide_view")), gtk_spin_button_get_value(spinner)/100);
+}
+
 void
 cria_main_window_show_about(CriaMainWindow* self) {
 	const gchar	* authors[] = {
