@@ -31,7 +31,8 @@
 
 G_BEGIN_DECLS
 
-CriaPresentation* cria_presentation_parser_get_new_presentation(GsfInput *input); 
+CriaPresentation* cria_presentation_parser_get_new_presentation(GsfInput* input,
+								GError	**error); 
 
 G_END_DECLS
 
