@@ -48,7 +48,7 @@ struct _CriaPresentationPrivate {
 
 enum {
 	PROP_0,
-	PROP_TITLE
+	PROP_TITLE,
 };
 
 enum {
@@ -132,10 +132,10 @@ cria_presentation_class_init (CriaPresentationClass	* cria_presentation_class)
 	g_object_class->set_property = cria_presentation_set_property;
 	g_object_class->get_property = cria_presentation_get_property;
 
-	g_object_class_install_property (
+	g_object_class_install_property(
 			g_object_class,
 			PROP_TITLE,
-			g_param_spec_string (
+			g_param_spec_string(
 				"title",
 				"Title",
 				"The title of the presentation",
@@ -158,7 +158,7 @@ cria_presentation_get_property (
 	switch (prop_id)
 	{
 	case PROP_TITLE:
-		g_value_set_string (
+		g_value_set_string(
 				value,
 				self->title);
 		break;
@@ -791,8 +791,8 @@ cria_sax_0_0_1_element_slide_start (
 			g_object_new (
 				CRIA_TYPE_SLIDE,
 				"title", g_hash_table_lookup (hash_table, "title"),
-				"theme", g_hash_table_lookup (hash_table, "theme"),
-				"layout", g_hash_table_lookup (hash_table, "layout"),
+				"theme", cria_presentation_get_theme(CRIA_PRESENTATION(data->tags->data), g_hash_table_lookup (hash_table, "theme")),
+				"layout", cria_theme_get_layout(cria_presentation_get_theme(CRIA_PRESENTATION(data->tags->data), g_hash_table_lookup (hash_table, "theme")),g_hash_table_lookup (hash_table, "layout")),
 				NULL)
 			);
 }
