@@ -36,6 +36,13 @@ typedef struct _CriaSlideList CriaSlideList;
 typedef struct _CriaSlideListClass CriaSlideListClass;
 typedef struct _CriaSlideListPrivate CriaSlideListPrivate;
 
+enum {
+	COLUMN_PREVIEW,
+	COLUMN_TITLE,
+	COLUMN_INDEX,
+	N_COLUMNS
+};
+
 GType		  cria_slide_list_get_type	       (void);
 CriaPresentation* cria_slide_list_get_presentation     (CriaSlideList	* self);
 void		  cria_slide_list_set_presentation     (CriaSlideList	* self,
